@@ -53,6 +53,15 @@ IV<-c(PA,PB)
   l1<-c("small effect size: <.87")
   l2<-c("medium effect size: .87 to 2.67 ")
   l3<-c("large effect size: >2.67")
+  writeLines(" ")
+  writeLines("****************************************************************************")
+  writeLines("Note: the ES index, d-index, and  Hedges's g index are unreliable")
+  writeLines("if any phase is autocorrelated or has a trend.")
+  writeLines("Use the TauU test if any phase is autocorrelated.")
+  writeLines("If no autocorrelation exists in any phase, but a trend exists,") 
+  writeLines("use the TauU or G-index test.")
+  writeLines("****************************************************************************")
+  writeLines(" ")
   writeLines(l1)
   writeLines(l2)
   writeLines(l3)
